@@ -189,3 +189,105 @@ interpolation.calibration<-function(object, stations = NULL, variable="Tmin", N_
   class(l)<-c("interpolation.calibration", "list")
   return(l)
 }
+
+interpolation.calibration.fmax<-function(object, stations = NULL, fmax_seq = seq(0.05,0.95, by=0.05), verbose = FALSE) {
+  if(!inherits(object, "MeteorologyInterpolationData")) stop("'object' has to be of class 'MeteorologyInterpolationData'")
+  if(is.null(stations)) stations = 1:length(object@elevation)
+  Osel = rep(FALSE, length(object@elevation))
+  Osel[stations] = TRUE
+  points = SpatialPoints(object@coords, object@proj4string)
+  mPar = object@params
+  MAE = numeric(length(fmax_seq))
+  names(MAE) = fmax_seq
+  Cmat = as.matrix(object@Precipitation)
+  Csmooth = object@SmoothedPrecipitation
+  cat(paste("Total number of stations: ", nrow(Cmat),"\n",sep=""))
+  Ccoords = object@coords
+  Celevation = object@elevation
+  Cnodatastations = (rowSums(is.na(Cmat))==ncol(Cmat))
+  Cmat = Cmat[!Cnodatastations,]
+  Ccoords = Ccoords[!Cnodatastations,]
+  Celevation = Celevation[!Cnodatastations]
+  Osel = Osel[!Cnodatastations]
+  cat(paste("Number of stations with available data: ", nrow(Cmat),"\n",sep=""))
+  stations = which(Osel)
+  
+  #Stations for the assessment of MAE
+  Omat = Cmat[stations,]
+  Ocoords = Ccoords[stations,]
+  Oelevation = Celevation[stations]
+  cat(paste("Number of stations used for MAE: ", length(stations),"\n",sep=""))
+  cat(paste("Number of parameter values to test: ", length(fmax_seq),"\n\n",sep=""))
+  #Initialize MAE to optimize
+  minMAE = 9999999.0
+  imin = NA
+  cat("Evaluation of fmax values\n")
+  if(!verbose) pb = txtProgressBar(0, length(fmax_seq), style=3)
+  for(i in 1:length(fmax_seq)) {
+    if(!verbose) setTxtProgressBar(pb, i)
+      Pmat = Omat
+      Pmat[] = 0.0
+      for(p in 1:length(stations)) {
+        station = stations[p]
+        mp= .interpolatePrecipitationSeriesPoints( Xp = Ocoords[p,1],
+                                                   Yp = Ocoords[p,2],
+                                                   Zp = Oelevation[p],
+                                                   X = Ccoords[-station,1],
+                                                   Y = Ccoords[-station,2],
+                                                   Z = Celevation[-station],
+                                                   P = Cmat[-station,],
+                                                   Psmooth = Csmooth[-station,],
+                                                   iniRp = mPar$initial_Rp,
+                                                   alpha_event = mPar$alpha_PrecipitationEvent,
+                                                   alpha_amount = mPar$alpha_PrecipitationAmount,
+                                                   N_event = mPar$N_PrecipitationEvent,
+                                                   N_amount = mPar$N_PrecipitationAmount,
+                                                   iterations = mPar$iterations,
+                                                   popcrit = mPar$pop_crit,
+                                                   fmax = fmax_seq[i])
+        Pmat[p,] = as.vector(mp)
+      }
+      if(sum(!is.na(Pmat))>0) {
+        den1 = 0
+        num1 = 0
+        num2 = 0
+        den2 = 0
+        for(d in 1:ncol(Omat)) {
+          oprec = Omat[,d]
+          pprec = Pmat[!is.na(oprec),d]
+          w = sum(!is.na(oprec))
+          so = sum(oprec, na.rm=TRUE)
+          sp = sum(pprec, na.rm=TRUE)
+          if(w>0) {
+            num1=num1+abs(sp/w - so/w)
+            den1 = den1 + 1
+          }
+        }
+        for(p in 1:nrow(Omat)) {
+          oprec = Omat[p,]
+          pprec = Pmat[p,!is.na(oprec)]
+          w = sum(!is.na(oprec))
+          so = sum(oprec, na.rm=TRUE)
+          sp = sum(pprec, na.rm=TRUE)
+          if(w>0) {
+            num2=num2+abs(sp/w - so/w)
+            den2 = den2 + 1
+          }
+        }
+        
+        # print(c(num,den))
+        MAE[i] = sqrt((num1/den1)*(num2/den2))
+        if(verbose) cat(paste("   fmax: ", fmax_seq[i], " MAE = ", MAE[i], "\n",sep=""))
+        if(MAE[i]<minMAE) {
+          minMAE = MAE[i]
+          imin = i
+          OmatOpt = Omat
+          PmatOpt = Pmat
+        }
+      }
+    }
+  cat(paste("\nMinimum MAE value: ", minMAE, " fmax: ", fmax_seq[imin], "\n",sep=""))
+  l = list(MAE = MAE, minMAE = minMAE, fmax = fmax_seq[imin], Observed = OmatOpt, Predicted = PmatOpt)
+  class(l)<-c("interpolation.calibration.fmax", "list")
+  return(l)
+}
\ No newline at end of file
