@@ -147,7 +147,7 @@ interpolationgrid<-function(object, grid, dates = NULL,
   if(!inherits(object,"MeteorologyInterpolationData")) stop("'object' has to be of class 'MeteorologyInterpolationData'.")
   if(!inherits(grid,"SpatialGridTopography")) stop("'grid' has to be of class 'SpatialGridTopography'.")
   if(!is.null(dates)) {
-    if(class(dates)!="Date") stop("'dates' has to be of class 'Date'.")
+    if(!inherits(dates,"Date")) stop("'dates' has to be of class 'Date'.")
     if(sum(as.character(dates) %in% as.character(object@dates))<length(dates)) 
       stop("At least one of the dates is outside the time period for which interpolation is possible.")
   }
